<?php
/**
 * Plugin Name: CD Dating Landing
 * Plugin URI: http://statsv3.carpediem.fr/
 * Description: Intégrez le landing à vos blogs rencontre en quelques clics ! 
 * Author: PhilippeCD
 * Version: 1.0
 * Author URI: https://be.linkedin.com/in/phscreation
 **/

if ( !class_exists('CD_Dating_landing') ) {

    class CD_Dating_landing {

        /**
		 * the Constructor
		 * @param void
		 * @return void
		 **/
		public function __construct()
		{

            // Admin zone
            add_action('admin_menu', array($this, 'adminLink')); // Admin menu link
            add_action('admin_init', array($this, 'adminInit')); // Admin options

            // Add the fields when we add|edit a post
            add_action('add_meta_boxes', array($this, 'addMeta')); // Add meta field
            add_action('save_post', array($this, 'postCheck')); // Check special fields & shedule
			add_action('edit_post', array($this, 'postCheck')); // Check special fields

            // Add tinyMCE button
            add_filter('mce_external_plugins', array($this, 'tinymce_plugin')); // Add plugin
            add_filter('mce_buttons', array($this, 'tinymce_button')); // Add button

            // Filter
            add_filter('the_content', array($this, 'shortcode'));

            // Add JS on the footer
            add_action( 'wp_footer', array($this, 'enqeue_script') );

        }

        /**
		 * Add the link into the admin menu
		 * @param void
		 * @return void
		 **/
		public function adminLink ()
		{
			add_menu_page( 'Dating Landing', 'Dating Landing', 'manage_options', 'my-cddatinglanding-admin', array($this, 'adminContent'), plugin_dir_url( __FILE__ ) . '/media/img/button.png');
		}

        /**
		 * Display the configuration page into the admin
		 * @param void
		 * @return void
		 **/
		public function adminContent ()
		{

			$this->options = get_option( 'cddatinglanding' );
			?>

			<div class="wrap">

				<h2>Dating Landing</h2>
                <p>Intégrez le landing de Carpe Diem en quelques clic à vos post : ne perdez plus de temps à poser du code HTML complexe :)</p>

                <?php if ( isset($_GET['settings-updated']) && $_GET['settings-updated'] == true ) : ?>
                    <div class='updated fade' style="background: #82FBD3; border-color: #57C21F;">
                        <p><strong>Configuration mise à jour avec succès.</strong></p>
                    </div>
                <?php endif; ?>

				<form method="post" action="options.php">
					<?php
					settings_fields( 'cddatinglanding_options' );
					do_settings_sections( 'my-cddatinglanding-admin' );
					submit_button();
					?>
				</form>

			</div>

			<?php
		}

        /**
		 * Make the options form
		 * @param void
		 * @return void
		 **/
		public function adminInit()
		{

			register_setting( 'cddatinglanding_options', 'cddatinglanding', array( $this, 'sanitize' ) );

			add_settings_section( 'cd_account', 'Votre compte CarpeDiem.fr', array( $this, 'introCd' ), 'my-cddatinglanding-admin' );  
			add_settings_field( 'id', 'ID Webmaster', array( $this, 'fieldCdIdWebmaster' ), 'my-cddatinglanding-admin', 'cd_account' );
			add_settings_field( 'tracker', 'Tracker', array( $this, 'fieldCdTracker' ), 'my-cddatinglanding-admin', 'cd_account' );

            add_settings_section( 'cd_promo', 'Configurez la promotion', array( $this, 'introPromo' ), 'my-cddatinglanding-admin' );  
			add_settings_field( 'id_mb', 'Niche / MB', array( $this, 'fieldPromoMB' ), 'my-cddatinglanding-admin', 'cd_promo' );
			add_settings_field( 'picType', 'Content', array( $this, 'fieldPromoContent' ), 'my-cddatinglanding-admin', 'cd_promo' );

            add_settings_section( 'cd_landing', 'Configurez le landing', array( $this, 'introLanding' ), 'my-cddatinglanding-admin' );  
			add_settings_field( 'logo_url', 'URL de votre logo', array( $this, 'fieldLandingLogo' ), 'my-cddatinglanding-admin', 'cd_landing' );
			add_settings_field( 'bgcolor', 'Couleur de background', array( $this, 'fieldLandingBgcolor' ), 'my-cddatinglanding-admin', 'cd_landing' );

		}

        /**
		 * Intro text in the admin for classic config
		 * @param void
		 * @return void
		 **/
		public function introCd ()
        {
            echo '<p>Entrez ci dessous les informations sur votre compte CarpeDiem.fr de façon à attribuer les ventes.</p>';
        }

        /** 
		 * Display ID webmaster field
		 * @param void
		 * @return void
		 **/
		public function fieldCdIdWebmaster()
		{
			printf(
				'<input type="text" id="id" name="cddatinglanding[id]" value="%s" />',
				isset( $this->options['id'] ) ? esc_attr( $this->options['id']) : ''
			);
		}

        /** 
		 * Display tracker field
		 * @param void
		 * @return void
		 **/
		public function fieldCdTracker()
		{
			printf(
				'<input type="text" id="tracker" name="cddatinglanding[tracker]" value="%s" />',
				isset( $this->options['tracker'] ) ? esc_attr( $this->options['tracker']) : ''
			);
		}

        /**
		 * Intro text in the admin for promo config
		 * @param void
		 * @return void
		 **/
		public function introPromo ()
        {
            echo '<p>Nichez votre landing afin que ce dernier colle à votre site.</p>';
        }

        /** 
		 * Display ID MB
		 * @param void
		 * @return void
		 **/
		public function fieldPromoMB()
		{
			printf(
				'<input type="text" id="id_mb" name="cddatinglanding[id_mb]" value="%s" /> <a href="http://www.carpediem.fr" onclick="document.getElementById(\'landingMbs\').style.display=\'block\';return false;">Voir les IDs</a>',
				isset( $this->options['id_mb'] ) ? esc_attr( $this->options['id_mb']) : ''
			);
            echo '<blockquote id="landingMbs" style="display: none;">'
				 . ' <strong>yes</strong> : Yes! Messenger<br>'
				 . ' <strong>rh</strong> : RencontresHard<br>'
				 . ' <strong>2840</strong> : Cougar Messenger<br>'
				 . ' <strong>2841</strong> : Infidèle Messenger<br>'
				 . ' <strong>2944</strong> : Asiat Messenger<br>'
				 . ' <strong>2945</strong> : Afro Messenger<br>'
				 . ' <strong>2946</strong> : Beurette Messenger<br>'
				 . ' <strong>2947</strong> : Transex Messenger<br>'
				 . ' ou votre ID (numérique) MB pour utiliser votre propre marque blanche.'
				 . '</blockquote>';
		}

        /** 
		 * Display picture types
		 * @param void
		 * @return void
		 **/
		public function fieldPromoContent()
		{
			printf('<select name="cddatinglanding[picType]" id="sound">');
            $array = array( 'soft', 'sexy', 'hard' );
            foreach ( $array as $value ) {
                $checked = ( !empty( $this->options['picType'] ) && esc_attr( $this->options['picType']) ==  $value) ? 'selected="selected"' : '';
                printf('<option value="' . $value . '" ' . $checked . '>' . ucfirst($value) . '</option>');
            }
            printf('</select>');
		}

        /**
		 * Intro text in the admin for landing config
		 * @param void
		 * @return void
		 **/
		public function introLanding ()
        {
            echo '<p>Intégrez votre logo et couleur de fond au landing pour le suivi marketing.</p>';
        }

        /** 
		 * Display landing logo
		 * @param void
		 * @return void
		 **/
		public function fieldLandingLogo()
		{
			printf(
				'<input type="text" id="logo_url" name="cddatinglanding[logo_url]" value="%s" /> Taille idéale : 272x32 px.',
				isset( $this->options['logo_url'] ) ? esc_attr( $this->options['logo_url']) : ''
			);
		}

        /** 
		 * Display bgcolor
		 * @param void
		 * @return void
		 **/
		public function fieldLandingBgcolor()
		{
			printf(
				'#<input type="text" id="bgcolor" name="cddatinglanding[bgcolor]" value="%s" />',
				isset( $this->options['bgcolor'] ) ? esc_attr( $this->options['bgcolor']) : ''
			);
		}

        /**
		 * Sanitize each setting field as needed
		 * @param array $input Contains all settings fields as array keys
		 * @return void
		 **/
		public function sanitize( $input )
		{

            // Default config
			$sanitizedArray = array(
                'id' => 10000,
                'tracker' => 'deftrack',
                'id_mb' => 'rh',
                'picType' => 'sexy',
                'logo_url' => '',
                'bgcolor' => '',
                );

             // Filter array
             $args = array(
                'id' => FILTER_VALIDATE_INT,
                'tracker' => array(
                    'filter' => FILTER_SANITIZE_STRING,
                    'flags' => FILTER_FLAG_STRIP_LOW|FILTER_FLAG_STRIP_HIGH
                    ),
                'id_mb' => array(
                    'filter' => FILTER_SANITIZE_STRING,
                    'flags' => FILTER_FLAG_STRIP_LOW|FILTER_FLAG_STRIP_HIGH
                    ),
                'picType' => array(
                    'filter' => FILTER_VALIDATE_REGEXP,
                    'options' => array('regexp' => '`^(soft|sexy|hard)$`')
                    ),
                'logo_url' => FILTER_VALIDATE_URL,
                'bgcolor' => array(
                    'filter' => FILTER_VALIDATE_REGEXP,
                    'options' => array('regexp' => '`^([a-zA-Z0-9]*)$`')
                    ),
                );

			return array_filter(array_merge($sanitizedArray, (array) filter_var_array($input, $args)));

		}

        /**
		 * Add meta box
		 * @param void
		 * @return void
		 **/
		function addMeta() {
 
			// Define the custom attachment for posts
			add_meta_box( 'wp_custom_meta', 'Profil associé au post', array($this, 'addMetaCallback'), 'post', 'normal', 'high' );

		}

        /**
		 * Meta box content
		 * @param void
		 * @return void
		 **/
		function addMetaCallback( $post )
		{

			wp_nonce_field( 'dating_metabox', 'dating_metabox_nonce' );

            $pseudo = get_post_meta( $post->ID, 'pseudo', true );
			$age = get_post_meta( $post->ID, 'age', true );
			$thumb = get_post_meta( $post->ID, 'thumb', true );
			$city = get_post_meta( $post->ID, 'city', true );

            if ( !empty($thumb) ) {
                echo '<table width="90%" align="center" border="0">'
                    .'    <tr>'
                    .'        <td width="210" style="padding: 10px;"><img src="' . esc_attr( $thumb ) . '" alt="' . esc_attr( $pseudo ) . ', ' . esc_attr( $age ) . ' ans" width="100%"></td>'
                    .'        <td align="left">'
                    .'            <p><strong><u>' . esc_attr( $pseudo ) . ', ' . esc_attr( $age ) . ' ans</u></strong></p>'
                    .'            <p><label for="dating_pseudo" style="display: inline-block; width: 150px;"><strong>Pseudo</strong></label><input type="text" id="dating_pseudo" name="dating_pseudo" value="' . esc_attr( $pseudo ) . '" placeholder="Pseudo (string)" size="50" /></p>'
                    .'            <p><label for="dating_age" style="display: inline-block; width: 150px;"><strong>Age</strong></label><input type="text" id="dating_age" name="dating_age" value="' . esc_attr( $age ) . '" placeholder="Age (int)" size="50" /></p>'
                    .'            <p><label for="dating_thumb" style="display: inline-block; width: 150px;"><strong>Thumb</strong></label><input type="text" id="dating_thumb" name="dating_thumb" value="' . esc_attr( $thumb ) . '" placeholder="URL de la thumb (URL absolue)" size="50" /></p>'
                    .'            <p><label for="dating_city" style="display: inline-block; width: 150px;"><strong>Ville</strong></label><input type="text" id="dating_city" name="dating_city" value="' . esc_attr( $city ) . '" placeholder="Nom de la ville (string)" size="50" /></p>'
                    .'        </td>'
                    .'    </tr>'
                    .'</table>'
                    .'<script> $(".wp-editor-area").css("height", "150px"); </script>';
            } else {
                echo '<table width="90%" align="center" border="0">'
                    .'    <tr>'
                    .'        <td align="left">'
                    .'            <p><label for="dating_pseudo" style="display: inline-block; width: 150px;"><strong>Pseudo</strong></label><input type="text" id="dating_pseudo" name="dating_pseudo" value="" placeholder="Pseudo (string)" size="50" /></p>'
                    .'            <p><label for="dating_age" style="display: inline-block; width: 150px;"><strong>Age</strong></label><input type="text" id="dating_age" name="dating_age" value="" placeholder="Age (int)" size="50" /></p>'
                    .'            <p><label for="dating_thumb" style="display: inline-block; width: 150px;"><strong>Thumb</strong></label><input type="text" id="dating_thumb" name="dating_thumb" value="" placeholder="URL de la thumb (URL absolue)" size="50" /></p>'
                    .'            <p><label for="dating_city" style="display: inline-block; width: 150px;"><strong>Ville</strong></label><input type="text" id="dating_city" name="dating_city" placeholder="Nom de la ville (string)" size="50" /></p>'
                    .'        </td>'
                    .'    </tr>'
                    .'</table>'
                    .'<script> $(".wp-editor-area").css("height", "150px"); </script>';
            }

		}

        /**
		 * Check meta datas of the post
		 * @param void
		 * @return void
		 **/
		public function postCheck( $postId )
		{

			// Nonce verification
			if ( ! isset( $_POST['dating_metabox_nonce'] ) || ! wp_verify_nonce( $_POST['dating_metabox_nonce'], 'dating_metabox' ) ) {
				return $postId;
			}

			// Auto-save or revision
			 if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || wp_is_post_revision($postId) ) {
				return $postId;
			}

			// Permission verification
			if ( !current_user_can( 'edit_post', $postId )) {
				return $postId;
			}

			$post = get_post($postId); 

			// Check pseudo
			$wpErrors = array();

			if (! isset($_POST['dating_pseudo']) ) {
				delete_post_meta($postId, 'pseudo');
			} else {
				update_post_meta($postId, 'pseudo', $_POST['dating_pseudo']);
			}

			if ( ! filter_var( $_POST['dating_age'], FILTER_VALIDATE_INT, array( 'options' => array( 'min_range' => 18, 'max_range' => 99 ) ) ) ) {
				delete_post_meta($postId, 'age');
			} else {
				update_post_meta($postId, 'age', $_POST['dating_age']);
			}

			if ( ! wp_remote_fopen($_POST['dating_thumb']) ) {
				delete_post_meta($postId, 'thumb');
			} else {
				update_post_meta($postId, 'thumb', $_POST['dating_thumb']);
			}

            if ( ! isset($_POST['dating_city']) ) {
				delete_post_meta($postId, 'city');
			} else {
				update_post_meta($postId, 'city', $_POST['dating_city']);
			}

		}

        /**
		 * Add the button on editor
		 * @param $buttons
		 * @return void
		 **/
		public function tinymce_button ( $buttons )
		{
			array_push($buttons, "Landing");
            return $buttons;
		}

        /**
		 * Add the button on editor
		 * @param $pluginArray
		 * @return void
		 **/
        public function tinymce_plugin($pluginArray) {
            $pluginArray['Landing'] = plugin_dir_url( __FILE__ ) . '/media/js/button.js';
            return $pluginArray;
        }

        /**
		 * Shortcode
		 * @param $content
		 * @return void
		 **/
		public function shortcode ( $content )
		{
			return preg_replace_callback("/\[landingUrl\]/", array($this, 'flvcashplayer_plugin_callback'), $content); 
		}

        /**
		 * Shortcode content
		 * @param void
		 * @return void
		 **/
        public function flvcashplayer_plugin_callback()
        {

            global $post;

            if ( empty($this->options) ) {
                $this->options = get_option( 'cddatinglanding' );
            }

            switch ( $this->options['id_mb'] ) {
                case 'yes':   default: $rotationID = 89; $landingBase = 'http://outils.yes-messenger.com/download.php'; break;
				case 'rh': $rotationID = 90; $landingBase = 'http://clouds.rencontreshard.com/download.php'; break;
				case 2840: $rotationID = 509; $landingBase = 'http://outils.cougarmessenger.com/download_c1.php'; break;
				case 2841: $rotationID = 510; $landingBase = 'http://outils.infidelemessenger.com/download_i1.php'; break;
				case 2944: $rotationID = 524; $landingBase = 'http://outils.asiatmessenger.com/download_j1.php'; break;
				case 2945: $rotationID = 525; $landingBase = 'http://outils.afromessenger.com/download_b1.php'; break;
				case 2946: $rotationID = 526; $landingBase = 'http://outils.beurettemessenger.com/download_bu1.php'; break;
				case 2947: $rotationID = 527; $landingBase = 'http://outils.transexmessenger.com/download_t1.php'; break;
            }

            // Get meta 
            $pseudo = get_post_meta( $post->ID, 'pseudo', true );
			$age = get_post_meta( $post->ID, 'age', true );
			$thumb = get_post_meta( $post->ID, 'thumb', true );
			$city = get_post_meta( $post->ID, 'city', true );

            $urlBase = 'http://www.espace-plus.net/redir/rotation_redir.php';
            $urlQs = array(
                'id_rotation' => $rotationID,
                'synergie' => 'hetero',
                'langue' => 'fr',
                'e' => 1,
                'w' => 0,
                'id' => $this->options['id'],
                'tracker' => $this->options['tracker'],
                );
            if ( !empty($thumb) ) {
                $urlBase = $landingBase;
                $urlQs = array(
                    'id' => $this->options['id'],
                    'tracker' => $this->options['tracker'],
                    'id_mb' => $this->options['id_mb'],
                    'picType' => $this->options['picType'],
                    'bgcolor' => $this->options['bgcolor'],
                    'logo_url' => $this->options['logo_url'],
                    'pseudo' => $pseudo,
                    'age' => $age,
                    'img_path' => $thumb,
                    );
                if ( !empty($city) ) {
                    $urlQs['showCity'] = $city;
                } 

            }

            $output = $urlBase . '?' . http_build_query($urlQs);
            return $output;

        }

        /**
		 * Footer scripts
		 * @param void
		 * @return void
		 **/
		public function enqeue_script (  )
		{
			wp_register_script( 'landing-script', plugins_url( 'media/js/footer.js', __FILE__ ) );
            wp_enqueue_script( 'landing-script' );
		}

    }

    $CD_Dating_landing = new CD_Dating_landing();

}